/*  smplayer, GUI front-end for mplayer.
    Copyright (C) 2007 Ricardo Villalba <rvm@escomposlinux.org>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include "baseguiplus.h"

#if QT_VERSION >= 0x040200
#include <Q3PopupMenu>
#include "myaction.h"
#include "global.h"
#include "images.h"
#include "playlist2.h"
//#include "infowindow.h"
#endif


BaseGuiPlus::BaseGuiPlus( QString file, QWidget * parent, const char* name, 
                          WFlags fl )
	: BaseGui( file, parent, name, fl )
{
	#if QT_VERSION >= 0x040200
	mainwindow_visible = true;
	playlist_visible = false;
	//infowindow_visible = false;
	mainwindow_pos = pos();

	tray = new QSystemTrayIcon( Images::icon("logo", 22), this );
	tray->setToolTip( "SMPlayer" );
	connect( tray, SIGNAL(activated(QSystemTrayIcon::ActivationReason)), 
             this, SLOT(trayIconActivated(QSystemTrayIcon::ActivationReason)));

	quitAct->addTo( openMenu );

	showTrayAct = new MyAction(this, "show_try_icon" );
	showTrayAct->setToggleAction(true);
	connect( showTrayAct, SIGNAL(toggled(bool)),
             tray, SLOT(setVisible(bool)) );
	showTrayAct->addTo( optionsMenu );

	showAllAct = new MyAction(this, "restore/hide");
	connect( showAllAct, SIGNAL(activated()),
             this, SLOT(toggleShowAll()) );

	context_menu = new Q3PopupMenu(this);
	showAllAct->addTo( context_menu );
	context_menu->addSeparator();
	openFileAct->addTo( context_menu );
	recents_menu_id = context_menu->insertItem( "Recents", recentfiles_menu );
	openDVDAct->addTo( context_menu );
	openURLAct->addTo( context_menu );
	context_menu->addSeparator();
	playOrPauseAct->addTo( context_menu );
	stopAct->addTo( context_menu );
	context_menu->addSeparator();
	playlist->playPrevAct()->addTo( context_menu );
	playlist->playNextAct()->addTo( context_menu );
	context_menu->addSeparator();
	showPlaylistAct->addTo( context_menu );
	showPreferencesAct->addTo( context_menu );
	context_menu->addSeparator();
	quitAct->addTo( context_menu );
	
	tray->setContextMenu( context_menu );
	#endif

	languageChange();

    loadConfig();
}

BaseGuiPlus::~BaseGuiPlus() {
	saveConfig();
}

void BaseGuiPlus::firstShow() {
	qDebug("BaseGuiPlus::firstShow");
	#if QT_VERSION >= 0x040200
	if ( (!showTrayAct->isOn()) || (!initial_file.isEmpty()) || (mainwindow_visible) ) {
		show();
	}
	#else
	BaseGui::firstShow();
	#endif
}

void BaseGuiPlus::closeEvent( QCloseEvent * e ) {
	#if QT_VERSION >= 0x040200
	if (tray->isVisible()) {
		e->ignore();
		showAll(false); // Hide windows
		if (core->state == PLAYING) core->stop();
		tray->showMessage( "SMPlayer", 
			tr("SMPlayer is still running here"), 
            QSystemTrayIcon::Information, 3000 );
	} else {
		BaseGui::closeEvent(e);
	}
	//tray->hide();
	#else
	BaseGui::closeEvent(e);
	#endif
}

void BaseGuiPlus::languageChange() {
	BaseGui::languageChange();

	#if QT_VERSION >= 0x040200
	showTrayAct->change( tr("S&how icon in system tray") );
	context_menu->changeItem( recents_menu_id, tr("&Recent files") );
	updateShowAllAct();
	#endif
}

void BaseGuiPlus::updateShowAllAct() {
	#if QT_VERSION >= 0x040200
	if (isVisible()) 
		showAllAct->change( tr("&Hide") );
	else
		showAllAct->change( tr("&Restore") );
	#endif
}

void BaseGuiPlus::saveConfig() {
	qDebug("BaseGuiPlus::saveConfig");

	#if QT_VERSION >= 0x040200

	QSettings * set = settings;

	set->beginGroup( "base_gui_plus");

	set->writeEntry( "show_tray_icon", showTrayAct->isOn() );
	set->writeEntry( "mainwindow_visible", isVisible() );

	set->endGroup();

	#endif
}

void BaseGuiPlus::loadConfig() {
	qDebug("BaseGuiPlus::loadConfig");

	#if QT_VERSION >= 0x040200

	QSettings * set = settings;

	set->beginGroup( "base_gui_plus");

	bool show_tray_icon = set->readBoolEntry( "show_tray_icon", false);
	showTrayAct->setOn( show_tray_icon );
	//tray->setVisible( show_tray_icon );

	mainwindow_visible = set->readBoolEntry("mainwindow_visible", true);

	set->endGroup();

	updateShowAllAct();
	#endif
}


void BaseGuiPlus::trayIconActivated(QSystemTrayIcon::ActivationReason reason) {
	#if QT_VERSION >= 0x040200
	qDebug("DefaultGui::trayIconActivated: %d", reason);

	updateShowAllAct();

	if (reason == QSystemTrayIcon::Trigger) {
		toggleShowAll();
	}
	#endif
}

void BaseGuiPlus::toggleShowAll() {
	#if QT_VERSION >= 0x040200
	showAll( !isVisible() );
	#endif
}

void BaseGuiPlus::showAll(bool b) {
	#if QT_VERSION >= 0x040200
	if (!b) {
		// Hide all
		mainwindow_pos = pos();
		hide();

		playlist_visible = playlist->isVisible();
		playlist_pos = playlist->pos();
		playlist->hide();

		/*
		infowindow_visible = info_window->isVisible();
		infowindow_pos = info_window->pos();
		info_window->hide();
		*/
	} else {
		// Show all
		move(mainwindow_pos);
		show();

		if (playlist_visible) {
			playlist->move(playlist_pos);
			playlist->show();
		}

		/*
		if (infowindow_visible) {
			info_window->show();
			info_window->move(infowindow_pos);
		}
		*/
	}
	updateShowAllAct();
	#endif
}

void BaseGuiPlus::resizeWindow(int w, int h) {
    qDebug("BaseGuiPlus::resizeWindow: %d, %d", w, h);

	#if QT_VERSION >= 0x040200
	if ( (tray->isVisible()) && (!isVisible()) ) showAll(true);
	#endif

	BaseGui::resizeWindow(w, h );
}

void BaseGuiPlus::updateMediaInfo() {
    qDebug("BaseGuiPlus::updateMediaInfo");
	BaseGui::updateMediaInfo();
	#if QT_VERSION >= 0x040200
	tray->setToolTip( caption() );
	#endif
}
