/*  smplayer, GUI front-end for mplayer.
    Copyright (C) 2007 Ricardo Villalba <rvm@escomposlinux.org>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include "floatingcontrol.h"

#include <qpushbutton.h>
#include "timeslider.h"
#include "qt3_4_compat.h"

#include <qlayout.h>
#include "images.h"
#include <qiconset.h>
#include <qlcdnumber.h>

FloatingControl::FloatingControl( QWidget * parent, const char * name)
	: QWidget( parent, name, Qt::WType_TopLevel | Qt::WStyle_Customize |
                             Qt::WStyle_NoBorder | Qt::WStyle_StaysOnTop | 
                             Qt::WX11BypassWM )
{

	rewind3 = new QPushButton(this, "rewind3");
	rewind2 = new QPushButton(this, "rewind2");
	rewind1 = new QPushButton(this, "rewind1");

	time = new TimeSlider(this, "time" );

	forward1 = new QPushButton(this, "forward1");
	forward2 = new QPushButton(this, "forward2");
	forward3 = new QPushButton(this, "forward3");

	rewind3->setFocusPolicy( NOFOCUS );
	rewind2->setFocusPolicy( NOFOCUS );
	rewind1->setFocusPolicy( NOFOCUS );

	forward1->setFocusPolicy( NOFOCUS );
	forward2->setFocusPolicy( NOFOCUS );
	forward3->setFocusPolicy( NOFOCUS );

	QBoxLayout * l1 = new QHBoxLayout(0,0,0);
	l1->addWidget( rewind3 );
	l1->addWidget( rewind2 );
	l1->addWidget( rewind1 );
	l1->addWidget( time );
	l1->addWidget( forward1 );
	l1->addWidget( forward2 );
	l1->addWidget( forward3 );

	play = new QPushButton(this, "play");
	pause = new QPushButton(this, "pause");
	stop = new QPushButton(this, "stop");

	QSpacerItem * spacer1 = new QSpacerItem( 20, 10, QSizePolicy::Expanding,
                                             QSizePolicy::Minimum );
	lcd = new QLCDNumber(this, "lcd" );
	lcd->setFrameShape( QFrame::WinPanel );
	lcd->setFrameShadow( QFrame::Sunken );
    #if QT_VERSION >= 0x040000
	lcd->setAutoFillBackground(TRUE);
	#endif
	lcd->setPaletteBackgroundColor( QColor(0,0,0) );
	lcd->setPaletteForegroundColor( QColor(200,200,200) );
	lcd->setSegmentStyle( QLCDNumber::Flat );
	lcd->setSizePolicy( QSizePolicy::Expanding, QSizePolicy::Fixed);

	QSpacerItem * spacer2 = new QSpacerItem( 20, 10, QSizePolicy::Expanding,
                                             QSizePolicy::Minimum );

	fullscreen = new QPushButton(this, "mute");
	fullscreen->setToggleButton(true);

	mute = new QPushButton(this, "mute");
	mute->setToggleButton(true);

	volume = new MySlider(this, "volume" );
	volume->setTickmarks( QSlider::Below );
	volume->setTickInterval( 10 );
	volume->setLineStep( 1 );
	volume->setPageStep( 10 );
	volume->setSizePolicy( QSizePolicy::Fixed, QSizePolicy::Fixed);

	play->setFocusPolicy( NOFOCUS );
	pause->setFocusPolicy( NOFOCUS );
	stop->setFocusPolicy( NOFOCUS );
	lcd->setFocusPolicy( NOFOCUS );
	fullscreen->setFocusPolicy( NOFOCUS );
	mute->setFocusPolicy( NOFOCUS );
	volume->setFocusPolicy( NOFOCUS );

	QBoxLayout * l2 = new QHBoxLayout(0,0,0);
	l2->addWidget( play );
	l2->addWidget( pause );
	l2->addWidget( stop );
	l2->addItem( spacer1 );
	l2->addWidget( lcd );
	l2->addItem( spacer2 );
	l2->addWidget( fullscreen );
	l2->addWidget( mute );
	l2->addWidget( volume );

	QBoxLayout * l = new QVBoxLayout(this, 4, 1);
	l->addLayout(l1);
	l->addLayout(l2);

	languageChange();

	setSizePolicy( QSizePolicy::Expanding, QSizePolicy::Fixed);
	adjustSize();
}


FloatingControl::~FloatingControl()
{
}

void FloatingControl::languageChange() {
	int size = 22;

	play->setPixmap( Images::icon("play", size) );
	pause->setPixmap( Images::icon("pause", size) );
	stop->setPixmap( Images::icon("stop", size) );

	forward1->setPixmap( Images::icon("forward10s", size) );
	forward2->setPixmap( Images::icon("forward1m", size) );
	forward3->setPixmap( Images::icon("forward10m", size) );

	rewind1->setPixmap( Images::icon("rewind10s", size) );
	rewind2->setPixmap( Images::icon("rewind1m", size) );
	rewind3->setPixmap( Images::icon("rewind10m", size) );

	fullscreen->setPixmap( Images::icon("fullscreen", size) );

	QIconSet icset( Images::icon("volume", size) );
	icset.setPixmap( Images::icon("mute", size), QIconSet::Automatic,
                     QIconSet::Normal, QIconSet::On  );
	mute->setIconSet( icset );
}
